"use strict";
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        get: all[name],
        enumerable: true
    });
}
_export(exports, {
    CompiledAttribute: ()=>CompiledAttribute,
    Scope: ()=>Scope,
    ScopeManager: ()=>ScopeManager
});
let CompiledAttribute = class CompiledAttribute {
    get isExpanded() {
        return this.expanded !== undefined;
    }
    get fullName() {
        return ScopeManager.prototype.getPath(this.scope) + this.name;
    }
    constructor(name, type, scope, source){
        this.name = name;
        this.type = type;
        this.scope = scope;
        this.source = source;
    }
};
let Scope = class Scope extends Map {
    constructor(name, parent){
        super();
        this.name = name;
        this.parent = parent;
        this.children = [];
    }
};
let ScopeManager = class ScopeManager {
    push(newScope) {
        if (typeof newScope == "string") {
            let name = newScope;
            newScope = new Scope(name);
        }
        var names = this.current.children.map((s)=>s.name);
        // console.log(this.current.name || "global", names);
        if (newScope.name[0] == "?") {
            let i = 0;
            while(names.includes(i + newScope.name))i++;
            newScope.name = i + newScope.name;
        } else if (names.includes(newScope.name)) {
            return false;
        }
        // this.stack.push(this.current);
        newScope.parent = this.current;
        this.current.children.push(newScope);
        this.current = newScope;
        return this.current;
    }
    pop() {
        if (this.current.parent) this.current = this.current.parent;
    }
    set(name, value) {
        this.current.set(name, new CompiledAttribute(name, value.type, this.current, value));
    }
    get(name, scope) {
        var s = scope || this.current;
        while(s){
            var x = s.get(name);
            if (x !== undefined) return x;
            s = s.parent;
        }
        //@ts-expect-error
        return undefined;
    }
    getPath(scope = (void 0).current) {
        var path = "";
        var s = scope;
        while(s){
            path = s.name + "::" + path;
            s = s.parent;
        }
        return path.slice(2);
    }
    constructor(){
        this.global = this.current = new Scope("");
    }
};

//# sourceMappingURL=ScopeManager.js.map