"use strict";
Object.defineProperty(exports, "createCommand", {
    get: ()=>createCommand,
    enumerable: true
});
const _fs = require("fs");
const _index = require("./index");
const _chalk = require("chalk");
const _commander = require("commander");
const _path = require("path");
const _utils = require("./utils");
//TODO: automate this
// prettier-ignore
const validTargets = {
    "none": [],
    "textmate": [
        "textmate.xml"
    ],
    "textmate.*": [
        "textmate.json",
        "textmate.xml"
    ],
    "textmate.json": [
        "textmate.json"
    ],
    "textmate.xml": [
        "textmate.xml"
    ],
    "ace": [
        "ace.js"
    ],
    "ace.*": [
        "ace.js",
        "ace.json"
    ],
    "ace.js": [
        "ace.js"
    ],
    "ace.json": [
        "ace.json"
    ],
    "ast": [
        "ast"
    ]
};
validTargets["tm"] = validTargets["textmate"];
validTargets["tm.json"] = validTargets["textmate.json"];
validTargets["tm.xml"] = validTargets["textmate.xml"];
validTargets["*"] = validTargets["all"] = [
    ...validTargets["textmate.*"],
    ...validTargets["ace.*"]
];
function createCommand(exitOnFail = false) {
    const program = new _commander.Command();
    program.name("iro").description("A grammar generator for syntax highlighters").version(require("../package.json").version, "-v, --version").showSuggestionAfterError();
    program.command("compile").argument("<source>").requiredOption("-t, --targets <targets>", "A comma-separated list of targets").option("-o, --out <path>", "The output directory (defaults to source directory)").option("-n, --name <name>", "Set the output files' name (defaults to name defined in grammar)").action((f, options)=>{
        const sourcePath = f;
        const targets = options.targets.replace("=", "").split(",").map((t)=>{
            var tt = validTargets[t];
            if (!tt) console.error(`${_chalk.yellow("warning")}: Skipping unknown target '${t}'`);
            return tt;
        }).flat(1).filter((t)=>t);
        const outputPath = options.out || _path.dirname(sourcePath);
        const input = _fs.readFileSync(sourcePath, "utf8");
        _fs.mkdirSync(outputPath, {
            recursive: true
        });
        console.log("Targets: " + targets.join(", ") + "\n");
        const start = process.hrtime();
        const result = (0, _index.compile)(input);
        const took = (process.hrtime(start)[1] / 1e6).toFixed(3) + " ms";
        const lines = input.split("\n");
        for (let error of result.errors){
            console.log((0, _utils.prettyError)(error, lines, _path.basename(sourcePath)));
        }
        if (result.errors.find((e)=>e.fatal)) {
            console.log("\n" + _chalk.red("Compilation failed"));
            if (exitOnFail) process.exit(1);
        } else {
            const grammarName = options.name || result.global.get("name")?.expanded || _path.basename(sourcePath);
            const writeOutput = (suffix, data, stringify = false)=>_fs.writeFileSync(_path.join(outputPath, grammarName + suffix), stringify ? JSON.stringify(data, null, 4) : data, "utf8");
            for (let t of targets){
                switch(t){
                    case "ast":
                        writeOutput(".ast.json", result.ast, true);
                        break;
                    case "textmate.json":
                        writeOutput(".tmlanguage.json", result.textmate, true);
                        break;
                    case "textmate.xml":
                        writeOutput(".tmlanguage", result.makeTextmateXML());
                        break;
                    case "ace.json":
                        writeOutput(".ace.json", result.ace, true);
                        break;
                    case "ace.js":
                        writeOutput(".ace.js", result.makeAceHighlighter({
                            spacing: 4
                        }));
                }
            }
            console.log("\nCompiled successfully in " + took);
        }
    });
    return program;
}

//# sourceMappingURL=cli.js.map