"use strict";
function _export(target, all) {
    for(var name in all)Object.defineProperty(target, name, {
        get: all[name],
        enumerable: true
    });
}
_export(exports, {
    ScopeManager: ()=>_scopeManager,
    compile: ()=>compile,
    compiler: ()=>_compiler,
    nodes: ()=>_nodes,
    parse: ()=>parse
});
const _nearley = require("nearley");
const _compiler = require("./compiler");
const _utils = require("./utils");
const _nodes = require("./nodes");
const _scopeManager = require("./ScopeManager");
const Rion = require("./rion");
const grammar = _nearley.Grammar.fromCompiled(Rion);
function getParser() {
    return new _nearley.Parser(grammar);
}
function parse(input) {
    const parser = new _nearley.Parser(grammar);
    var r = parser.feed(input).results[0];
    if (!r) {
        throw {
            message: "Unexpected end of input",
            offset: parser.current,
            token: {
                text: "",
                value: "",
                col: parser.lexerState?.col,
                line: parser.lexerState?.line,
                type: "EOF",
                lineBreaks: 0,
                offset: parser.lexer.index || 0
            }
        };
    }
    return r;
}
function compile(input, options) {
    var ast;
    if (typeof input == "string") {
        var parsed;
        try {
            parsed = parse(input);
        } catch (e) {
            if (!(0, _utils.isNearleyError)(e)) throw e;
            let lines = input.split("\n");
            if (e.token) {
                // Parser error
                let start = {
                    column: e.token.col - 1,
                    line: e.token.line,
                    offset: e.token.offset
                };
                let end = {
                    column: e.token.col - 1 + e.token.value.length,
                    line: e.token.line,
                    offset: e.token.offset + e.token.value.length
                };
                return {
                    errors: [
                        {
                            fatal: true,
                            message: `Unexpected ${e.token.type} token '${e.token.value}'`,
                            location: {
                                start,
                                end
                            }
                        }, 
                    ]
                };
            } else {
                // Lexer error
                let linecol = e.message.match(/invalid syntax at line (\d+) col (\d+):/);
                if (!linecol) linecol = [
                    "0",
                    "1",
                    "1"
                ];
                let loc = {
                    column: +linecol[2] - 1,
                    line: +linecol[1],
                    offset: e.offset
                };
                return {
                    errors: [
                        {
                            fatal: true,
                            message: `Unexpected token '${lines[loc.line - 1][loc.column]}'`,
                            location: {
                                start: loc,
                                end: loc
                            }
                        }, 
                    ]
                };
            }
        }
        ast = parsed;
    } else ast = input;
    var result = (0, _compiler.compile)(ast, options);
    return result;
}

//# sourceMappingURL=index.js.map