"use strict";
const _fs = require("fs");
const _index = require("./index");
const _utils = require("./utils");
var input = _fs.readFileSync("./test/grammars/test.iro", "utf8");
var parsed;
console.time("parsing took");
try {
    parsed = (0, _index.parse)(input);
} catch (e) {
    console.log(e.message);
    let lines = input.split("\n");
    let linecol = e.message.match(/invalid syntax at line (\d+) col (\d+):/);
    if (linecol) {
        let loc = {
            column: +linecol[2] - 1,
            line: +linecol[1],
            offset: e.offset
        };
        console.log((0, _utils.prettyError)({
            fatal: true,
            message: "Invalid syntax",
            location: {
                start: loc,
                end: loc
            }
        }, lines));
    }
}
console.timeEnd("parsing took");
if (parsed) {
    _fs.mkdirSync("out", {
        recursive: true
    });
    _fs.writeFileSync("out/ast.json", JSON.stringify(parsed, null, 4), "utf8");
    console.time("compiling took");
    var result = (0, _index.compile)(parsed, {
        targets: [
            "textmate",
            "ace"
        ]
    });
    console.timeEnd("compiling took");
    _fs.writeFileSync("out/tmlanguage.json", JSON.stringify(result.textmate, null, 4), "utf8");
    _fs.writeFileSync("out/tmlanguage.plist", result.makeTextmateXML(), "utf8");
    _fs.writeFileSync("out/ace.json", JSON.stringify(result.ace, null, 4), "utf8");
    _fs.writeFileSync("out/ace.js", result.makeAceHighlighter({
        spacing: 4
    }), "utf8");
    var lines1 = input.split("\n");
    for (let error of result.errors){
        console.log((0, _utils.prettyError)(error, lines1));
    }
}

//# sourceMappingURL=test.js.map